<?php
namespace Elementor;

/**
 * @package     WordPress
 * @subpackage  Hover Box for Elementor
 * @author      support@themegum.com
 * @since       1.0.0
*/

if ( ! defined( 'ABSPATH' ) ) {
  exit; // Exit if accessed directly.
}



use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Border;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Icons_Manager;
use Elementor\Repeater;

/**
 * Elementor hover box widget.
 *
 *
 * @since 1.0.0
 */
class Widget_Temegum_Hover_Box extends Widget_Base {


  public function __construct( $data = [], $args = null ) {
    parent::__construct( $data, $args );

    $is_type_instance = $this->is_type_instance();

    if ( ! $is_type_instance && null === $args ) {
      throw new \Exception( '`$args` argument is required when initializing a full widget instance.' );
    }

    add_action( 'elementor/element/before_section_start', [ $this, 'enqueue_script' ] );

    if ( $is_type_instance ) {
      $this->_register_skins();

      $widget_name = $this->get_name();

      /**
       * Widget skin init.
       *
       * Fires when Elementor widget is being initialized.
       *
       * The dynamic portion of the hook name, `$widget_name`, refers to the widget name.
       *
       * @since 1.0.0
       *
       * @param Widget_Base $this The current widget.
       */
      do_action( "elementor/widget/{$widget_name}/skins_init", $this );
    }
  }


  /**
   * Get widget name.
   *
   * Retrieve button widget name.
   *
   * @since 1.0.0
   * @access public
   *
   * @return string Widget name.
   */
  public function get_name() {
    return 'el-hvrbx';
  }

  /**
   * Get widget title.
   *
   * Retrieve button widget title.
   *
   * @since 1.0.0
   * @access public
   *
   * @return string Widget title.
   */
  public function get_title() {
    return esc_html__( 'Hover Box', 'hover-box-for-elementor' );
  }

  /**
   * Get widget icon.
   *
   * Retrieve button widget icon.
   *
   * @since 1.0.0
   * @access public
   *
   * @return string Widget icon.
   */
  public function get_icon() {
    return 'fa fa-clone';
  }

  /**
   * Get widget categories.
   *
   * Retrieve the list of categories the button widget belongs to.
   *
   * Used to determine where to display the widget in the editor.
   *
   * @since 2.0.0
   * @access public
   *
   * @return array Widget categories.
   */
  public function get_categories() {
    return [ 'temegum' ];
  }

  /**
   * Get button sizes.
   *
   * Retrieve an array of button sizes for the button widget.
   *
   * @since 1.0.0
   * @access public
   * @static
   *
   * @return array An array containing button sizes.
   */
  public static function get_button_sizes() {
    return [
      'xs' => esc_html__( 'Extra Small', 'hover-box-for-elementor' ),
      'sm' => esc_html__( 'Small', 'hover-box-for-elementor' ),
      'md' => esc_html__( 'Medium', 'hover-box-for-elementor' ),
      'lg' => esc_html__( 'Large', 'hover-box-for-elementor' ),
      'xl' => esc_html__( 'Extra Large', 'hover-box-for-elementor' ),
    ];
  }

  /**
   * Register button widget controls.
   *
   * Adds different input fields to allow the user to change and customize the widget settings.
   *
   * @since 1.0.0
   * @access protected
   */
  protected function _register_controls() {


    $this->start_controls_section(
      'section_box',
      [
        'label' => esc_html__( 'Box', 'hover-box-for-elementor' ),
      ]
    );

    $this->add_responsive_control(
      'box_height',
      [
        'label' => esc_html__( 'Height', 'hover-box-for-elementor' ),
        'type' => Controls_Manager::SLIDER,
        'range' => [
          'px' => [
            'max' => 1000,
          ],
          'step' => 10,
        ],
        'default' => [
            'size' => 400,
        ],
        'selectors' => [
          '{{WRAPPER}} .wl_hover_box' => 'min-height: {{SIZE}}{{UNIT}};',
        ],
      ]
    );
    $this->end_controls_section();

    $this->start_controls_section(
      'section_normal',
      [
        'label' => esc_html__( 'Normal Content', 'hover-box-for-elementor' ),
      ]
    );

    $this->add_control(
      'out_animation',
      [
        'label' => esc_html__( 'Out Animation', 'hover-box-for-elementor' ),
        'type' => Controls_Manager::SELECT,
        'default' => '',
        'options' => [
            ''       => esc_html__('None','hover-box-for-elementor'),
            'zoom-in'       => esc_html__('Zoom in','hover-box-for-elementor'),
            'zoom-out'       => esc_html__('Zoom out','hover-box-for-elementor'),
            'fade-out'       => esc_html__('Fade out','hover-box-for-elementor'),
            'to-left'       => esc_html__('Slide Out Left','hover-box-for-elementor'),
            'to-right'         => esc_html__('Slide Out Right','hover-box-for-elementor'),
            'up'       => esc_html__('Slide Out Up','hover-box-for-elementor'),
            'down'         => esc_html__('Slide Out Down','hover-box-for-elementor'),
        ],
      ]
    );

    $this->add_control(
      'out_animation_transition',
      [
        'label' => esc_html__( 'Transition Duration', 'hover-box-for-elementor' ),
        'type' => Controls_Manager::SLIDER,
        'default' => [
          'size' => 0.6,
        ],
        'range' => [
          'px' => [
            'max' => 3,
            'step' => 0.1,
          ],
        ],
        'condition' => [
          'out_animation[value]!' => '',
        ],
        'selectors' => [
          '{{WRAPPER}} .hover-content.background' => 'transition-duration: {{SIZE}}s;',
        ],
      ]
    );


    $this->add_control(
      'normal_content',
      [
        'label' => esc_html__( 'Content', 'hover-box-for-elementor' ),
        'type' => Controls_Manager::TEXTAREA,
        'default' => '',
        'label_block' => true,
      ]
    );


    $this->add_responsive_control(
      'text_align',
      [
        'label' => esc_html__( 'Alignment', 'hover-box-for-elementor' ),
        'type' => Controls_Manager::CHOOSE,
        'options' => [
          'left' => [
            'title' => esc_html__( 'Left', 'hover-box-for-elementor' ),
            'icon' => 'eicon-text-align-left',
          ],
          'center' => [
            'title' => esc_html__( 'Center', 'hover-box-for-elementor' ),
            'icon' => 'eicon-text-align-center',
          ],
          'right' => [
            'title' => esc_html__( 'Right', 'hover-box-for-elementor' ),
            'icon' => 'eicon-text-align-right',
          ],
          'justify' => [
            'title' => esc_html__( 'Justified', 'hover-box-for-elementor' ),
            'icon' => 'eicon-text-align-justify',
          ],
        ],
        'default'=>'center',
        'selectors' => [
          '{{WRAPPER}} .hover-content.background .hover-box-inner' => 'text-align: {{VALUE}};',
        ],
      ]
    );


    $this->add_responsive_control(
      'normal_vertical_align',
      [
        'label' => esc_html__( 'Vertical Align', 'hover-box-for-elementor' ),
        'type' => Controls_Manager::CHOOSE,
        'options' => [
          '' => [
            'title' => esc_html__( 'Top', 'hover-box-for-elementor' ),
            'icon' => 'eicon-v-align-top',
          ],
          'middle' => [
            'title' => esc_html__( 'Middle', 'hover-box-for-elementor' ),
            'icon' => 'eicon-v-align-middle',
          ],
          'bottom' => [
            'title' => esc_html__( 'Bottom', 'hover-box-for-elementor' ),
            'icon' => 'eicon-v-align-bottom',
          ],
        ],
        'default'=>'middle',
      ]
    );


    $this->end_controls_section();

    $this->start_controls_section(
      'section_hover',
      [
        'label' => esc_html__( 'Hover Content', 'hover-box-for-elementor' ),

      ]
    );


    $this->add_control(
      'in_animation',
      [
        'label' => esc_html__( 'In Animation', 'hover-box-for-elementor' ),
        'type' => Controls_Manager::SELECT,
        'default' => '',
        'options' => [
            ''       => esc_html__('None','hover-box-for-elementor'),
            'zoom-in'       => esc_html__('Zoom in','hover-box-for-elementor'),
            'zoom-out'       => esc_html__('Zoom out','hover-box-for-elementor'),
            'fade-in'       => esc_html__('Fade in','hover-box-for-elementor'),
            'from-left'       => esc_html__('Slide In Right','hover-box-for-elementor'),
            'from-right'         => esc_html__('Slide In Left','hover-box-for-elementor'),
            'from-top'       => esc_html__('Slide In Down','hover-box-for-elementor'),
            'from-bottom'         => esc_html__('Slide In Up','hover-box-for-elementor'),
            'scale-up'         => esc_html__('Scale up','hover-box-for-elementor'),
            'scale-down'         => esc_html__('Scale down','hover-box-for-elementor'),
        ],
      ]
    );


    $this->add_control(
      'in_animation_transition',
      [
        'label' => esc_html__( 'Transition Duration', 'hover-box-for-elementor' ),
        'type' => Controls_Manager::SLIDER,
        'default' => [
          'size' => 0.6,
        ],
        'range' => [
          'px' => [
            'max' => 3,
            'step' => 0.1,
          ],
        ],
        'condition' => [
          'in_animation[value]!' => '',
        ],
        'selectors' => [
          '{{WRAPPER}} .hover-content.foreground' => 'transition-duration: {{SIZE}}s;',
          '{{WRAPPER}} .hover-content.foreground .hover-box-inner' => 'transition-duration: {{SIZE}}s;',
        ],
      ]
    );


    $this->add_control(
      'hover_content',
      [
        'label' => esc_html__( 'Content', 'hover-box-for-elementor' ),
        'type' => Controls_Manager::TEXTAREA,
        'default' => '',
        'label_block' => true,
        'description' => esc_html__( 'Please hover on box for preview.', 'hover-box-for-elementor' ),
      ]
    );


    $this->add_responsive_control(
      'hover_text_align',
      [
        'label' => esc_html__( 'Alignment', 'hover-box-for-elementor' ),
        'type' => Controls_Manager::CHOOSE,
        'options' => [
          'left' => [
            'title' => esc_html__( 'Left', 'hover-box-for-elementor' ),
            'icon' => 'eicon-text-align-left',
          ],
          'center' => [
            'title' => esc_html__( 'Center', 'hover-box-for-elementor' ),
            'icon' => 'eicon-text-align-center',
          ],
          'right' => [
            'title' => esc_html__( 'Right', 'hover-box-for-elementor' ),
            'icon' => 'eicon-text-align-right',
          ],
          'justify' => [
            'title' => esc_html__( 'Justified', 'hover-box-for-elementor' ),
            'icon' => 'eicon-text-align-justify',
          ],
        ],
        'default'=>'center',
        'selectors' => [
          '{{WRAPPER}} .hover-content.foreground .hover-box-inner' => 'text-align: {{VALUE}};',
        ],
      ]
    );


    $this->add_responsive_control(
      'hover_vertical_align',
      [
        'label' => esc_html__( 'Vertical Align', 'hover-box-for-elementor' ),
        'type' => Controls_Manager::CHOOSE,
        'options' => [
          '' => [
            'title' => esc_html__( 'Top', 'hover-box-for-elementor' ),
            'icon' => 'eicon-v-align-top',
          ],
          'middle' => [
            'title' => esc_html__( 'Middle', 'hover-box-for-elementor' ),
            'icon' => 'eicon-v-align-middle',
          ],
          'bottom' => [
            'title' => esc_html__( 'Bottom', 'hover-box-for-elementor' ),
            'icon' => 'eicon-v-align-bottom',
          ],
        ],
        'default'=>'middle',
      ]
    );


    $this->add_control(
      'show_button',
      [
        'label' => esc_html__( '1st Button', 'hover-box-for-elementor' ),
        'type' => Controls_Manager::SWITCHER,
        'label_off' => esc_html__( 'Hide', 'hover-box-for-elementor' ),
        'label_on' => esc_html__( 'Show', 'hover-box-for-elementor' ),
        'default' => 'no',
      ]
    );


    $this->add_control(
      'show_button_alt',
      [
        'label' => esc_html__( '2nd Button', 'hover-box-for-elementor' ),
        'type' => Controls_Manager::SWITCHER,
        'label_off' => esc_html__( 'Hide', 'hover-box-for-elementor' ),
        'label_on' => esc_html__( 'Show', 'hover-box-for-elementor' ),
        'default' => 'no',
        'condition' => ['show_button[value]' => 'yes']
      ]
    );


    $this->end_controls_section();

    $this->start_controls_section(
      'button_content',
      [
        'label' => esc_html__( '1st Button', 'hover-box-for-elementor' ),
        'condition' => ['show_button[value]' => 'yes']
      ]
    );    


    $this->add_control(
      'button_position',
      [
        'label' => esc_html__( 'Position', 'hover-box-for-elementor' ),
        'type' => Controls_Manager::SELECT,
        'default' => 'after',
        'options' => [
          'before' => esc_html__( 'Before Content', 'hover-box-for-elementor' ),
          'after' => esc_html__( 'After Content', 'hover-box-for-elementor' ),
        ],
      ]
    );


    $this->add_control(
      'button_text',
      [
        'label' => esc_html__( 'Text', 'hover-box-for-elementor' ),
        'type' => Controls_Manager::TEXT,
        'dynamic' => [
          'active' => true,
        ],
        'default' => esc_html__( 'Click here', 'hover-box-for-elementor' ),
        'placeholder' => esc_html__( 'Click here', 'hover-box-for-elementor' ),
      ]
    );

    $this->add_control(
      'button_link',
      [
        'label' => esc_html__( 'Link', 'hover-box-for-elementor' ),
        'type' => Controls_Manager::URL,
        'dynamic' => [
          'active' => true,
        ],
        'placeholder' => esc_html__( 'https://your-link.com', 'hover-box-for-elementor' ),
        'default' => [
          'url' => '#',
        ],
      ]
    );


    $this->add_control(
      'button_size',
      [
        'label' => esc_html__( 'Size', 'hover-box-for-elementor' ),
        'type' => Controls_Manager::SELECT,
        'default' => 'sm',
        'options' => self::get_button_sizes(),
        'style_transfer' => true,
      ]
    );


    $this->add_control(
      'selected_icon',
      [
        'label' => esc_html__( 'Icon', 'hover-box-for-elementor' ),
        'type' => Controls_Manager::ICONS,
        'fa4compatibility' => 'icon',
      ]
    );

    $this->add_control(
      'icon_align',
      [
        'label' => esc_html__( 'Icon Position', 'hover-box-for-elementor' ),
        'type' => Controls_Manager::SELECT,
        'default' => 'left',
        'options' => [
          'left' => esc_html__( 'Before', 'hover-box-for-elementor' ),
          'right' => esc_html__( 'After', 'hover-box-for-elementor' ),
        ],
        'condition' => [
          'selected_icon[value]!' => '',
        ],
      ]
    );

    $this->add_control(
      'view',
      [
        'label' => esc_html__( 'View', 'hover-box-for-elementor' ),
        'type' => Controls_Manager::HIDDEN,
        'default' => 'traditional',
      ]
    );

    $this->add_control(
      'button_css_id',
      [
        'label' => esc_html__( 'Button ID', 'hover-box-for-elementor' ),
        'type' => Controls_Manager::TEXT,
        'dynamic' => [
          'active' => true,
        ],
        'default' => '',
        'title' => esc_html__( 'Add your custom id WITHOUT the Pound key. e.g: my-id', 'hover-box-for-elementor' ),
        'description' => esc_html__( 'Please make sure the ID is unique and not used elsewhere on the page this form is displayed. This field allows <code>A-z 0-9</code> & underscore chars without spaces.', 'hover-box-for-elementor' ),
        'separator' => 'before',

      ]
    );

    $this->end_controls_section();

    $this->start_controls_section(
      'button_content_alt',
      [
        'label' => esc_html__( '2nd Button', 'hover-box-for-elementor' ),
        'condition' => ['show_button[value]' => 'yes','show_button_alt[value]' => 'yes']
      ]
    );    


    $this->add_control(
      'button_position_alt',
      [
        'label' => esc_html__( 'Position', 'hover-box-for-elementor' ),
        'type' => Controls_Manager::SELECT,
        'default' => 'after',
        'options' => [
          'before' => esc_html__( 'Before Content', 'hover-box-for-elementor' ),
          'after' => esc_html__( 'After Content', 'hover-box-for-elementor' ),
        ],
      ]
    );


    $this->add_control(
      'button_text_alt',
      [
        'label' => esc_html__( 'Text', 'hover-box-for-elementor' ),
        'type' => Controls_Manager::TEXT,
        'dynamic' => [
          'active' => true,
        ],
        'default' => esc_html__( 'Click here', 'hover-box-for-elementor' ),
        'placeholder' => esc_html__( 'Click here', 'hover-box-for-elementor' ),
      ]
    );

    $this->add_control(
      'button_link_alt',
      [
        'label' => esc_html__( 'Link', 'hover-box-for-elementor' ),
        'type' => Controls_Manager::URL,
        'dynamic' => [
          'active' => true,
        ],
        'placeholder' => esc_html__( 'https://your-link.com', 'hover-box-for-elementor' ),
        'default' => [
          'url' => '#',
        ],
      ]
    );


    $this->add_control(
      'button_size_alt',
      [
        'label' => esc_html__( 'Size', 'hover-box-for-elementor' ),
        'type' => Controls_Manager::SELECT,
        'default' => 'sm',
        'options' => self::get_button_sizes(),
        'style_transfer' => true,
      ]
    );


    $this->add_control(
      'selected_icon_alt',
      [
        'label' => esc_html__( 'Icon', 'hover-box-for-elementor' ),
        'type' => Controls_Manager::ICONS,
        'fa4compatibility' => 'icon',
      ]
    );

    $this->add_control(
      'icon_align_alt',
      [
        'label' => esc_html__( 'Icon Position', 'hover-box-for-elementor' ),
        'type' => Controls_Manager::SELECT,
        'default' => 'left',
        'options' => [
          'left' => esc_html__( 'Before', 'hover-box-for-elementor' ),
          'right' => esc_html__( 'After', 'hover-box-for-elementor' ),
        ],
        'condition' => [
          'selected_icon_alt[value]!' => '',
        ],
      ]
    );

    $this->add_control(
      'view_alt',
      [
        'label' => esc_html__( 'View', 'hover-box-for-elementor' ),
        'type' => Controls_Manager::HIDDEN,
        'default' => 'traditional',
      ]
    );

    $this->add_control(
      'button_css_id_alt',
      [
        'label' => esc_html__( 'Button ID', 'hover-box-for-elementor' ),
        'type' => Controls_Manager::TEXT,
        'dynamic' => [
          'active' => true,
        ],
        'default' => '',
        'title' => esc_html__( 'Add your custom id WITHOUT the Pound key. e.g: my-id', 'hover-box-for-elementor' ),
        'description' => esc_html__( 'Please make sure the ID is unique and not used elsewhere on the page this form is displayed. This field allows <code>A-z 0-9</code> & underscore chars without spaces.', 'hover-box-for-elementor' ),
        'separator' => 'before',

      ]
    );

    $this->end_controls_section();

    $this->start_controls_section(
      'section_normal_styles',
      [
        'label' => esc_html__( 'Normal Content', 'hover-box-for-elementor' ),
        'tab' => Controls_Manager::TAB_STYLE,
      ]
    );


    $this->add_group_control(
      Group_Control_Background::get_type(),
      [
        'name' => 'normal_background',
        'label' => esc_html__( 'Background', 'hover-box-for-elementor' ),
        'types' => [ 'classic'],
        'selector' => '{{WRAPPER}} .hover-content.background',
      ]
    );


    $this->add_responsive_control(
      'section_normal_padding',
      [
        'label' => esc_html__( 'Padding', 'hover-box-for-elementor' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', 'em', '%' ],
        'selectors' => [
          '{{WRAPPER}} .hover-content.background .hover-box-inner' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
      ]
    );



    $this->add_control(
      'section_normal_color',
      [
        'label' => esc_html__( 'Text Color', 'hover-box-for-elementor' ),
        'type' => Controls_Manager::COLOR,
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} .hover-content.background .text' => 'color: {{VALUE}};',
        ],
      ]
    );

    $this->add_group_control(
      Group_Control_Typography::get_type(),
      [
        'name' => 'section_normal_typography',
        'selector' => '{{WRAPPER}} .hover-content.background .text',
      ]
    );

  $this->end_controls_section();

   $this->start_controls_section(
      'section_hover_styles',
      [
        'label' => esc_html__( 'Hover Content', 'hover-box-for-elementor' ),
        'tab' => Controls_Manager::TAB_STYLE,
      ]
    );

  $this->add_group_control(
      Group_Control_Background::get_type(),
      [
        'name' => 'section_hover_bgcolor',
        'label' => esc_html__( 'Background', 'hover-box-for-elementor' ),
        'types' => [ 'classic'],
        'selector' => '{{WRAPPER}} .hover-content.foreground',
      ]
    );


    $this->add_responsive_control(
      'section_hover_padding',
      [
        'label' => esc_html__( 'Padding', 'hover-box-for-elementor' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', 'em', '%' ],
        'selectors' => [
          '{{WRAPPER}} .hover-content.foreground .hover-box-inner' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'description' => esc_html__( 'Please hover on box for preview.', 'hover-box-for-elementor' ),
      ]
    );


    $this->add_control(
      'section_hover_color',
      [
        'label' => esc_html__( 'Text Color', 'hover-box-for-elementor' ),
        'type' => Controls_Manager::COLOR,
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} .hover-content.foreground .text' => 'color: {{VALUE}};',
        ],
      ]
    );

    $this->add_group_control(
      Group_Control_Typography::get_type(),
      [
        'name' => 'section_hover_typography',
        'selector' => '{{WRAPPER}} .hover-content.foreground .text',
      ]
    );

    $this->end_controls_section();

    $this->start_controls_section(
      'section_button_styles',
      [
        'label' => esc_html__( '1st Button', 'hover-box-for-elementor' ),
        'tab' => Controls_Manager::TAB_STYLE,
        'condition' => ['show_button[value]' => 'yes']
      ]
    );

    $this->add_control(
      'icon_indent',
      [
        'label' => esc_html__( 'Icon Spacing', 'hover-box-for-elementor' ),
        'type' => Controls_Manager::SLIDER,
        'range' => [
          'px' => [
            'max' => 100,
          ],
        ],
        'selectors' => [
          '{{WRAPPER}} .elementor-button .elementor-align-icon-right' => 'margin-left: {{SIZE}}{{UNIT}};',
          '{{WRAPPER}} .elementor-button .elementor-align-icon-left' => 'margin-right: {{SIZE}}{{UNIT}};',
        ],
      ]
    );


    $this->add_control(
      'button_indent',
      [
        'label' => esc_html__( 'Vertical Spacing', 'hover-box-for-elementor' ),
        'type' => Controls_Manager::SLIDER,
        'range' => [
          'px' => [
            'max' => 200,
          ],
        ],
        'selectors' => [
          '{{WRAPPER}} .hover-box-inner .text + .elementor-button' => 'margin-top: {{SIZE}}{{UNIT}};',
          '{{WRAPPER}} .elementor-button + .text' => 'margin-top: {{SIZE}}{{UNIT}};',
          '{{WRAPPER}} .elementor-button + .elementor-button.secondary-button' => 'margin-top: {{SIZE}}{{UNIT}};',
        ],
      ]
    );


    $this->add_group_control(
     Group_Control_Typography::get_type(),
      [
        'name' => 'typography',
        'selector' => '{{WRAPPER}} .elementor-button',
      ]
    );

    $this->add_group_control(
     Group_Control_Text_Shadow::get_type(),
      [
        'name' => 'text_shadow',
        'selector' => '{{WRAPPER}} .elementor-button',
      ]
    );


    $this->add_group_control(
     Group_Control_Border::get_type(),
      [
        'name' => 'button_border',
        'selector' => '{{WRAPPER}} .elementor-button',
        'separator' => 'before',
      ]
    );

    $this->add_control(
      'button_border_radius',
      [
        'label' => esc_html__( 'Border Radius', 'hover-box-for-elementor' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', '%' ],
        'selectors' => [
          '{{WRAPPER}} .elementor-button' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );

    $this->add_group_control(
     Group_Control_Box_Shadow::get_type(),
      [
        'name' => 'button_box_shadow',
        'selector' => '{{WRAPPER}} .elementor-button',
      ]
    );

    $this->add_responsive_control(
      'button_text_padding',
      [
        'label' => esc_html__( 'Padding', 'hover-box-for-elementor' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', 'em', '%' ],
        'selectors' => [
          '{{WRAPPER}} .elementor-button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );


    $this->start_controls_tabs( 'tabs_button_style' );

    $this->start_controls_tab(
      'tab_button_normal',
      [
        'label' => esc_html__( 'Normal', 'hover-box-for-elementor' ),
      ]
    );

    $this->add_control(
      'button_text_color',
      [
        'label' => esc_html__( 'Text Color', 'hover-box-for-elementor' ),
        'type' => Controls_Manager::COLOR,
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} .elementor-button' => 'fill: {{VALUE}}; color: {{VALUE}};',
        ],
      ]
    );

    $this->add_control(
      'button_background_color',
      [
        'label' => esc_html__( 'Background Color', 'hover-box-for-elementor' ),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .elementor-button' => 'background-color: {{VALUE}};',
        ],
      ]
    );

    $this->end_controls_tab();

    $this->start_controls_tab(
      'tab_button_hover',
      [
        'label' => esc_html__( 'Hover', 'hover-box-for-elementor' ),
      ]
    );

    $this->add_control(
      'button_hover_color',
      [
        'label' => esc_html__( 'Text Color', 'hover-box-for-elementor' ),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .elementor-button:hover, {{WRAPPER}} .elementor-button:focus' => 'color: {{VALUE}};',
          '{{WRAPPER}} .elementor-button:hover svg, {{WRAPPER}} .elementor-button:focus svg' => 'fill: {{VALUE}};',
        ],
      ]
    );

    $this->add_control(
      'button_background_hover_color',
      [
        'label' => esc_html__( 'Background Color', 'hover-box-for-elementor' ),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .elementor-button:hover, {{WRAPPER}} .elementor-button:focus' => 'background-color: {{VALUE}};',
        ],
      ]
    );

    $this->add_control(
      'button_hover_border_color',
      [
        'label' => esc_html__( 'Border Color', 'hover-box-for-elementor' ),
        'type' => Controls_Manager::COLOR,
        'condition' => [
          'border_border!' => '',
        ],
        'selectors' => [
          '{{WRAPPER}} .elementor-button:hover, {{WRAPPER}} .elementor-button:focus' => 'border-color: {{VALUE}};',
        ],
      ]
    );

    $this->add_control(
      'button_hover_animation',
      [
        'label' => esc_html__( 'Hover Animation', 'hover-box-for-elementor' ),
        'type' => Controls_Manager::HOVER_ANIMATION,
      ]
    );

    $this->end_controls_tab();
    $this->end_controls_tabs();

    $this->end_controls_section();
    $this->start_controls_section(
      'section_button_styles_alt',
      [
        'label' => esc_html__( '2nd Button', 'hover-box-for-elementor' ),
        'tab' => Controls_Manager::TAB_STYLE,
        'condition' => ['show_button[value]' => 'yes','show_button_alt[value]' => 'yes']
      ]
    );


    $this->add_control(
      'button_alt_indent',
      [
        'label' => esc_html__( 'Button Spacing', 'hover-box-for-elementor' ),
        'type' => Controls_Manager::SLIDER,
        'range' => [
          'px' => [
            'max' => 200,
          ],
        ],
        'selectors' => [
          '{{WRAPPER}} .elementor-button.secondary-button' => 'margin-left: {{SIZE}}{{UNIT}};',
        ]
      ]
    );


    $this->add_control(
      'button_alt_styled',
      [
        'label' => esc_html__( 'Use Custom Button Style', 'hover-box-for-elementor' ),
        'type' => Controls_Manager::SWITCHER,
        'label_off' => esc_html__( 'No', 'hover-box-for-elementor' ),
        'label_on' => esc_html__( 'Yes', 'hover-box-for-elementor' ),
        'default' => 'no',
        'description' => esc_html__( 'Different style from 1st button', 'hover-box-for-elementor' ),

      ]
    );


    $this->add_control(
      'icon_indent_alt',
      [
        'label' => esc_html__( 'Icon Spacing', 'hover-box-for-elementor' ),
        'type' => Controls_Manager::SLIDER,
        'range' => [
          'px' => [
            'max' => 100,
          ],
        ],
        'selectors' => [
          '{{WRAPPER}} .elementor-button.secondary-button .elementor-align-icon-right' => 'margin-left: {{SIZE}}{{UNIT}};',
          '{{WRAPPER}} .elementor-button.secondary-button .elementor-align-icon-left' => 'margin-right: {{SIZE}}{{UNIT}};',
        ],
        'condition' => ['button_alt_styled'=>'yes']
      ]
    );


    $this->add_control(
      'button_indent_alt',
      [
        'label' => esc_html__( 'Vertical Spacing', 'hover-box-for-elementor' ),
        'type' => Controls_Manager::SLIDER,
        'range' => [
          'px' => [
            'max' => 200,
          ],
        ],
        'selectors' => [
          '{{WRAPPER}} .hover-box-inner .text + .elementor-button.secondary-button' => 'margin-top: {{SIZE}}{{UNIT}};',
          '{{WRAPPER}} .elementor-button.secondary-button  + .text' => 'margin-top: {{SIZE}}{{UNIT}};',
        ],
        'condition' => ['button_alt_styled'=>'yes']
      ]
    );


    $this->add_group_control(
     Group_Control_Typography::get_type(),
      [
        'name' => 'typography_alt',
        'selector' => '{{WRAPPER}} .elementor-button.secondary-button',
        'condition' => ['button_alt_styled'=>'yes']
      ]
    );

    $this->add_group_control(
     Group_Control_Text_Shadow::get_type(),
      [
        'name' => 'text_shadow_alt',
        'selector' => '{{WRAPPER}} .elementor-button.secondary-button',
        'condition' => ['button_alt_styled'=>'yes']
      ]
    );


    $this->add_group_control(
     Group_Control_Border::get_type(),
      [
        'name' => 'button_border_alt',
        'selector' => '{{WRAPPER}} .elementor-button.secondary-button',
        'separator' => 'before',
        'condition' => ['button_alt_styled'=>'yes']
      ]
    );

    $this->add_control(
      'button_border_radius_alt',
      [
        'label' => esc_html__( 'Border Radius', 'hover-box-for-elementor' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', '%' ],
        'selectors' => [
          '{{WRAPPER}} .elementor-button.secondary-button' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
        'condition' => ['button_alt_styled'=>'yes']
      ]
    );

    $this->add_group_control(
     Group_Control_Box_Shadow::get_type(),
      [
        'name' => 'button_box_shadow_alt',
        'selector' => '{{WRAPPER}} .elementor-button.secondary-button',
        'condition' => ['button_alt_styled'=>'yes']
      ]
    );

    $this->add_responsive_control(
      'button_text_padding_alt',
      [
        'label' => esc_html__( 'Padding', 'hover-box-for-elementor' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', 'em', '%' ],
        'selectors' => [
          '{{WRAPPER}} .elementor-button.secondary-button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
        'condition' => ['button_alt_styled'=>'yes']
      ]
    );


    $this->start_controls_tabs( 'tabs_button_style_alt',['condition' => ['button_alt_styled'=>'yes']] );

    $this->start_controls_tab(
      'tab_button_normal_alt',
      [
        'label' => esc_html__( 'Normal', 'hover-box-for-elementor' ),
      ]
    );

    $this->add_control(
      'button_text_color_alt',
      [
        'label' => esc_html__( 'Text Color', 'hover-box-for-elementor' ),
        'type' => Controls_Manager::COLOR,
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} .elementor-button.secondary-button' => 'fill: {{VALUE}}; color: {{VALUE}};',
        ],
        'condition' => ['button_alt_styled'=>'yes']
      ]
    );

    $this->add_control(
      'button_background_color_alt',
      [
        'label' => esc_html__( 'Background Color', 'hover-box-for-elementor' ),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .elementor-button.secondary-button' => 'background-color: {{VALUE}};',
        ],
        'condition' => ['button_alt_styled'=>'yes']
      ]
    );

    $this->end_controls_tab();

    $this->start_controls_tab(
      'tab_button_hover_alt',
      [
        'label' => esc_html__( 'Hover', 'hover-box-for-elementor' ),
      ]
    );

    $this->add_control(
      'button_hover_color_alt',
      [
        'label' => esc_html__( 'Text Color', 'hover-box-for-elementor' ),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .elementor-button.secondary-button:hover, {{WRAPPER}} .elementor-button.secondary-button:focus' => 'color: {{VALUE}};',
          '{{WRAPPER}} .elementor-button.secondary-button:hover svg, {{WRAPPER}} .elementor-button.secondary-button:focus svg' => 'fill: {{VALUE}};',
        ],
        'condition' => ['button_alt_styled'=>'yes']
      ]
    );

    $this->add_control(
      'button_background_hover_color_alt',
      [
        'label' => esc_html__( 'Background Color', 'hover-box-for-elementor' ),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .elementor-button.secondary-button:hover, {{WRAPPER}} .elementor-button.secondary-button:focus' => 'background-color: {{VALUE}};',
        ],
        'condition' => ['button_alt_styled'=>'yes']
      ]
    );

    $this->add_control(
      'button_hover_border_color_alt',
      [
        'label' => esc_html__( 'Border Color', 'hover-box-for-elementor' ),
        'type' => Controls_Manager::COLOR,
        'condition' => [
          'border_border!' => '',
        ],
        'selectors' => [
          '{{WRAPPER}} .elementor-button.secondary-button:hover, {{WRAPPER}} .elementor-button.secondary-button:focus' => 'border-color: {{VALUE}};',
        ],
        'condition' => ['button_alt_styled'=>'yes']
      ]
    );

    $this->add_control(
      'button_hover_animation_alt',
      [
        'label' => esc_html__( 'Hover Animation', 'hover-box-for-elementor' ),
        'type' => Controls_Manager::HOVER_ANIMATION,
        'condition' => ['button_alt_styled'=>'yes']
      ]
    );

    $this->end_controls_tab();
    $this->end_controls_tabs();
    $this->end_controls_section();

    }

  /**
   * Render button widget output on the frontend.
   *
   * Written in PHP and used to generate the final HTML.
   *
   * @since 1.0.0
   * @access protected
   */
  protected function render() {
    $settings = $this->get_settings_for_display();

    $this->add_render_attribute( 'wrapper', 'class', 'wl_hover_box' );
    ?>
    <div <?php echo $this->get_render_attribute_string( 'wrapper' ); ?>>
        <?php $this->render_background(); ?>
        <?php $this->render_foreground(); ?>
    </div>
    <?php
  }

  /**
   * Render hover background widget output in the editor.
   *
   *
   * @since 1.o.0
   * @access protected
   */

  protected function render_background() {

    $settings = $this->get_settings_for_display();


    $this->add_render_attribute( [
      'background-wrapper' => [
        'class' => ['hover-content','background','effect-'.$settings['out_animation'],'position-'.$settings['normal_vertical_align']]
      ],
    ] );

    $this->add_render_attribute( 'normal_content_inner', 'class', 'hover-box-inner' );

    ?>
    <div <?php echo $this->get_render_attribute_string( 'background-wrapper' ); ?>>
      <div <?php echo $this->get_render_attribute_string( 'normal_content_inner' ); ?>><?php 

      if ( ! Utils::is_empty( $settings['normal_content'] ) ) {

        $this->add_inline_editing_attributes( 'normal_content' );
        printf( '<div class="text">%s</div>', $settings['normal_content'] );
      }
      ?></div>
    </div>
    <?php
  }

  /**
   * Render hover foreground widget output in the editor.
   *
   *
   * @since 1.o.0
   * @access protected
   */

  protected function render_foreground() {

    $settings = $this->get_settings_for_display();

    $this->add_render_attribute( [
      'foreground-wrapper' => [
        'class' => ['hover-content','foreground','effect-'.$settings['in_animation'],'position-'.$settings['hover_vertical_align']]
      ],
    ] );

    $this->add_render_attribute( 'hover_content_inner', 'class', 'hover-box-inner' );

    ?>
    <div <?php echo $this->get_render_attribute_string( 'foreground-wrapper' ); ?>>
      <div <?php echo $this->get_render_attribute_string( 'hover_content_inner' ); ?>><?php 

      if($settings['show_button']=='yes' && $settings['button_position'] == 'before'){
        $this->render_button();
      }

      if($settings['show_button']=='yes' && $settings['show_button_alt']=='yes' && $settings['button_position_alt'] == 'before'){
        $this->render_button_alt();
      }

      if ( ! Utils::is_empty( $settings['hover_content'] ) ) {

        $this->add_inline_editing_attributes( 'hover_content' );

        printf( '<div class="text">%s</div>', $settings['hover_content'] );
      }

      if($settings['show_button']=='yes' && $settings['button_position'] == 'after'){
        $this->render_button();
      }


      if($settings['show_button']=='yes' && $settings['show_button_alt']=='yes' && $settings['button_position_alt'] == 'after'){
        $this->render_button_alt();
      }


      ?></div>
    </div>
    <?php
  } 


  /**
   * Render foreground button widget output in the editor.
   *
   *
   * @since 1.0.0
   * @access protected
   */

  protected function render_button() {

    $settings = $this->get_settings_for_display();

    $this->add_render_attribute( 'button' ,
      [
        'class' => ['elementor-button','primary-button'],
        'role' => 'button'
      ]
    );

    if ( ! empty( $settings['button_link']['url'] ) ) {
      $this->add_link_attributes( 'button', $settings['button_link'] );
      $this->add_render_attribute( 'button', 'class', 'elementor-button-link' );
    }

    if ( ! empty( $settings['button_css_id'] ) ) {
      $this->add_render_attribute( 'button', 'id', $settings['button_css_id'] );
    }

    if ( ! empty( $settings['button_size'] ) ) {
      $this->add_render_attribute( 'button', 'class', 'elementor-size-' . $settings['button_size'] );
    }


    if ( $settings['button_hover_animation'] ) {
      $this->add_render_attribute( 'button', 'class', 'elementor-animation-' . $settings['button_hover_animation'] );
    }


    $migrated = isset( $settings['__fa4_migrated']['selected_icon'] );
    $is_new = empty( $settings['icon'] ) && Icons_Manager::is_migration_allowed();

    if ( ! $is_new && empty( $settings['icon_align'] ) ) {
      // @todo: remove when deprecated
      // added as bc in 2.6
      //old default
      $settings['icon_align'] = $this->get_settings( 'icon_align' );
    }

    $this->add_render_attribute( [
      'icon-align' => [
        'class' => [
          'elementor-button-icon',
          'elementor-align-icon-' . $settings['icon_align'],
        ],
      ],
    ] );

    $this->add_inline_editing_attributes( 'button_text', 'none' );

    ?>
    <a <?php echo $this->get_render_attribute_string( 'button' ); ?>>
          <span class="elementor-button-content-wrapper">
      <?php if ( ! empty( $settings['icon'] ) || ! empty( $settings['selected_icon']['value'] ) ) : ?>
      <span <?php echo $this->get_render_attribute_string( 'icon-align' ); ?>>
        <?php if ( $is_new || $migrated ) :
          Icons_Manager::render_icon( $settings['selected_icon'], [ 'aria-hidden' => 'true' ] );
        else : ?>
          <i class="<?php echo esc_attr( $settings['icon'] ); ?>" aria-hidden="true"></i>
        <?php endif; ?>
      </span>
      <?php endif; ?>
      <span class="elementor-button-text"><?php echo $settings['button_text']; ?></span>
    </span>
  </a>
    <?php
  } 


  protected function render_button_alt() {

    $settings = $this->get_settings_for_display();

    $this->add_render_attribute( 'button_alt' ,
      [
        'class' => ['elementor-button','secondary-button'],
        'role' => 'button'
      ]
    );

    if($settings['button_alt_styled']!='yes'){
      $settings['button_hover_animation_alt'] = $settings['button_hover_animation'];
    }

    if ( ! empty( $settings['button_link_alt']['url'] ) ) {
      $this->add_link_attributes( 'button_alt', $settings['button_link_alt'] );
      $this->add_render_attribute( 'button_alt', 'class', 'elementor-button-link' );
    }


    if ( ! empty( $settings['button_css_id_alt'] ) ) {
      $this->add_render_attribute( 'button_alt', 'id', $settings['button_css_id_alt'] );
    }

    if ( ! empty( $settings['button_size_alt'] ) ) {
      $this->add_render_attribute( 'button_alt', 'class', 'elementor-size-' . $settings['button_size_alt'] );
    }

    if ( $settings['button_hover_animation_alt'] ) {
      $this->add_render_attribute( 'button_alt', 'class', 'elementor-animation-' . $settings['button_hover_animation_alt'] );
    }

    $migrated = isset( $settings['__fa4_migrated']['selected_icon_alt'] );
    $is_new = empty( $settings['icon_alt'] ) && Icons_Manager::is_migration_allowed();

    if ( ! $is_new && empty( $settings['icon_align_alt'] ) ) {
      // @todo: remove when deprecated
      // added as bc in 2.6
      //old default
      $settings['icon_align_alt'] = $this->get_settings( 'icon_align_alt' );
    }

    $this->add_render_attribute( [
      'icon-alt-align' => [
        'class' => [
          'elementor-button-icon',
          'elementor-align-icon-' . $settings['icon_align_alt'],
        ],
      ],
    ] );

    $this->add_inline_editing_attributes( 'button_text_alt', 'none' );
    ?>
    <a <?php echo $this->get_render_attribute_string( 'button_alt' ); ?>>
    <span class="elementor-button-content-wrapper">
      <?php if ( ! empty( $settings['icon_alt'] ) || ! empty( $settings['selected_icon_alt']['value'] ) ) : ?>
      <span <?php echo $this->get_render_attribute_string( 'icon-alt-align' ); ?>>
        <?php if ( $is_new || $migrated ) :
          Icons_Manager::render_icon( $settings['selected_icon_alt'], [ 'aria-hidden' => 'true' ] );
        else : ?>
          <i class="<?php echo esc_attr( $settings['icon_alt'] ); ?>" aria-hidden="true"></i>
        <?php endif; ?>
      </span>
      <?php endif; ?>
      <span class="elementor-button-text"><?php echo $settings['button_text_alt']; ?></span>
    </span>
      </a>
    <?php
  } 

  /**
   * Render  output in the editor.
   *
   * Written as a Backbone JavaScript template and used to generate the live preview.
   *
   * @since 2.9.0
   * @access protected
   */
  protected function content_template() {
    ?>
    <#
    view.addRenderAttribute( 'button_text', 'class', 'elementor-button-text' );
    view.addRenderAttribute( 'button_text_alt', 'class', 'elementor-button-text' );
    view.addInlineEditingAttributes( 'button_text', 'none' );
    view.addInlineEditingAttributes( 'button_text_alt', 'none' );

    view.addRenderAttribute( 'normal_content', 'class', 'text' );
    view.addRenderAttribute( 'hover_content', 'class', 'text' );


    var iconHTML = elementor.helpers.renderIcon( view, settings.selected_icon, { 'aria-hidden': true }, 'i' , 'object' ),
      migrated = elementor.helpers.isIconMigrated( settings, 'selected_icon' );
    var icon_altHTML = elementor.helpers.renderIcon( view, settings.selected_icon_alt, { 'aria-hidden': true }, 'i' , 'object' );


    if(settings.button_alt_styled!='yes'){
      settings.button_hover_animation_alt = settings.button_hover_animation;
    }

    #>
    <div class="wl_hover_box">
      <div class="hover-content background effect-{{ settings.out_animation }} position-{{settings.normal_vertical_align}}"><div class="hover-box-inner">
        <# if  ( settings.normal_content ){ 
        view.addInlineEditingAttributes( 'normal_content' );
        #>
        <div {{{ view.getRenderAttributeString( 'normal_content' ) }}}>{{{ settings.normal_content }}}</div>
        <# } #></div></div>
      <div class="hover-content foreground effect-{{ settings.in_animation }} position-{{settings.hover_vertical_align}}"><div class="hover-box-inner">
        <# 

        if  ( settings.show_button == 'yes' && settings.button_position == 'before'){ #>
      <a id="{{ settings.button_css_id }}" class="elementor-button elementor-size-{{ settings.button_size }} elementor-animation-{{ settings.button_hover_animation }}" href="{{ settings.button_link.url }}" role="button">
        <span class="elementor-button-content-wrapper">
          <# if ( settings.icon || settings.selected_icon ) { #>
          <span class="elementor-button-icon elementor-align-icon-{{ settings.icon_align }}">
            <# if ( ( migrated || ! settings.icon ) && iconHTML.rendered ) { #>
              {{{ iconHTML.value }}}
            <# } else { #>
              <i class="{{ settings.icon }}" aria-hidden="true"></i>
            <# } #>
          </span>
          <# } #>
          <span {{{ view.getRenderAttributeString( 'button_text' ) }}}>{{{ settings.button_text }}}</span>
        </span>
      </a>
        <# } 
      if  ( settings.show_button == 'yes' && settings.show_button_alt == 'yes' && settings.button_position_alt == 'before'){ #>
      <a id="{{ settings.button_css_id_alt }}" class="elementor-button secondary-button elementor-size-{{ settings.button_size_alt }} elementor-animation-{{ settings.button_hover_animation_alt }}" href="{{ settings.button_link_alt.url }}" role="button">
        <span class="elementor-button-content-wrapper">
          <# if ( settings.icon_alt || settings.selected_icon_alt ) { #>
          <span class="elementor-button-icon elementor-align-icon-{{ settings.icon_align_alt }}">
            <# if ( ( migrated || ! settings.icon_alt ) && icon_altHTML.rendered ) { #>
              {{{ icon_altHTML.value }}}
            <# } else { #>
              <i class="{{ settings.icon_alt }}" aria-hidden="true"></i>
            <# } #>
          </span>
          <# } #>
          <span {{{ view.getRenderAttributeString( 'button_text_alt' ) }}}>{{{ settings.button_text_alt }}}</span>
        </span>
      </a>
        <# }

        if  ( settings.hover_content ){  
          view.addInlineEditingAttributes( 'hover_content' ); 
        #>
        <div {{{ view.getRenderAttributeString( 'hover_content' ) }}}>{{{ settings.hover_content }}}</div>
        <# } 
        if  ( settings.show_button == 'yes' && settings.button_position == 'after'){ #>
      <a id="{{ settings.button_css_id }}" class="elementor-button elementor-size-{{ settings.button_size }} elementor-animation-{{ settings.button_hover_animation }}" href="{{ settings.button_link.url }}" role="button">
        <span class="elementor-button-content-wrapper">
          <# if ( settings.icon || settings.selected_icon ) { #>
          <span class="elementor-button-icon elementor-align-icon-{{ settings.icon_align }}">
            <# if ( ( migrated || ! settings.icon ) && iconHTML.rendered ) { #>
              {{{ iconHTML.value }}}
            <# } else { #>
              <i class="{{ settings.icon }}" aria-hidden="true"></i>
            <# } #>
          </span>
          <# } #>
          <span {{{ view.getRenderAttributeString( 'button_text' ) }}}>{{{ settings.button_text }}}</span>
        </span>
      </a>
        <# }

      if  ( settings.show_button == 'yes' && settings.show_button_alt == 'yes' && settings.button_position_alt == 'after'){ #>
      <a id="{{ settings.button_css_id_alt }}" class="elementor-button secondary-button elementor-size-{{ settings.button_size_alt }} elementor-animation-{{ settings.button_hover_animation_alt }}" href="{{ settings.button_link_alt.url }}" role="button">
        <span class="elementor-button-content-wrapper">
          <# if ( settings.icon_alt || settings.selected_icon_alt ) { #>
          <span class="elementor-button-icon elementor-align-icon-{{ settings.icon_align_alt }}">
            <# if ( ( migrated || ! settings.icon_alt ) && icon_altHTML.rendered ) { #>
              {{{ icon_altHTML.value }}}
            <# } else { #>
              <i class="{{ settings.icon_alt }}" aria-hidden="true"></i>
            <# } #>
          </span>
          <# } #>
          <span {{{ view.getRenderAttributeString( 'button_text_alt' ) }}}>{{{ settings.button_text_alt }}}</span>
        </span>
      </a>
        <# }
         #>
      </div></div>
    </div>
    <?php
  }


  public function enqueue_script( ) {

    wp_enqueue_style( 'hover-box-elementor',HOVER_BOX_ELEMENTOR_URL."css/style.css",array());

  }

}

// Register widget
\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widget_Temegum_Hover_Box() );
?>
